<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\SessionController;
use App\Http\Controllers\AdminDashboardController;
use App\Http\Controllers\AdminSessionController;
use App\Http\Controllers\DiagnosedController;
use App\Http\Controllers\DiseaseController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\RuleController;
use App\Http\Controllers\SymptomController;
use App\Http\Controllers\UserController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


Route::get('/', [SessionController::class,'index'])->name('session.index');
Route::post('/', [SessionController::class,'store'])->name('session.store');
Route::post('/register', [SessionController::class,'create'])->name('session.create');
Route::post('/user/logout', [SessionController::class,'destroy'])->name('session.destroy');

Route::middleware(['user'])->group(function () {

    Route::get('/home', [HomeController::class,'index'])->name('home.index');

    Route::get('/diagnosed', [DiagnosedController::class,'index'])->name('diagnosed.index');
    Route::post('/diagnose', [DiagnosedController::class, 'diagnose'])->name('diagnose');
    Route::get('/diagnosed/diagnosed', [DiagnosedController::class, 'showResult'])->name('diagnosed.diagnosed');

    Route::post('/userEdit', [HomeController::class, 'update'])->name('userUpdate');

});

    Route::get('/adminlogin', [AdminSessionController::class,'index'])->name('adminsession.index');
    Route::post('/adminlogin', [AdminSessionController::class,'store'])->name('adminsession.store');
    Route::post('/adminregister', [AdminSessionController::class,'create'])->name('adminsession.create');
    Route::post('/admin/logout', [AdminSessionController::class,'destroy'])->name('adminsession.destroy');

Route::middleware(['admin'])->group(function () {

    Route::get('/dashboard', [AdminDashboardController::class,'index'])->name('admindashboard.index');

    Route::get('/symptom', [SymptomController::class, 'index'])->name('symptom.index');
    Route::post('/symptomAdd', [SymptomController::class, 'create'])->name('symptom.create');
    Route::post('/symptomUpdate/{id}', [SymptomController::class, 'update'])->name('symptom.update');
    Route::delete('/symptomDelete/{id}', [SymptomController::class, 'destroy'])->name('symptom.destroy');

    Route::get('/disease', [DiseaseController::class, 'index'])->name('disease.index');
    Route::post('/diseaseAdd', [DiseaseController::class, 'create'])->name('disease.create');
    Route::post('/diseaseUpdate/{id}', [DiseaseController::class, 'update'])->name('disease.update');
    Route::delete('/diseaseDelete/{id}', [DiseaseController::class, 'destroy'])->name('disease.destroy');

    Route::get('/rule', [RuleController::class, 'index'])->name('rule.index');
    Route::post('/ruleAdd', [RuleController::class, 'create'])->name('rule.create');

    Route::post('/save-rule', [RuleController::class, 'store'])->name('save-rule');

    Route::post('/delete-unchecked', [RuleController::class, 'deleteUnchecked']);

    Route::get('/user', [UserController::class, 'index'])->name('user.index');
    Route::post('/userUpdate/{id}', [UserController::class, 'update'])->name('user.update');
    Route::post('/userAdd', [UserController::class, 'create'])->name('user.create');
    Route::delete('/userDelete/{id}', [UserController::class, 'destroy'])->name('user.destroy');
});


